@@ -131,7 +131,7 @@ class Config:
         else:
             print(
                 "Preparing is the next stage to run; "
-                "(tea workflow prepare -n <number of workers>)\n\n"
+                "(tea workflow prepare -n <number of workers> -s <seed for shuffle>)\n\n"
             )
             return
 
