@@ -20,22 +20,42 @@ from pangeamt_nlp.multilingual_resource.dataset.dataset_reader import (
 from pangeamt_nlp.multilingual_resource.dataset.dataset import Dataset
 
 
+NUM_GOOD_LINES = 0
+DROPPED_FROM = {}
+SEGMENT_FROM = {}
+
+
 def process(data, pipeline):
-    seg = Seg(data[0], data[1])
+    resource_index = data[0]
+    text = data[1]
+    seg = Seg(text[0], text[1])
     try:
         pipeline.process(seg)
-        data = (seg.src, seg.tgt)
-        return data
+        text = (seg.src, seg.tgt)
+        return (resource_index, text)
     except Exception as e:
-        return e
+        return (resource_index, e)
 
 
-def post(data, src_file, tgt_file, debug, log_file):
-    if not isinstance(data, Exception):
-        src_file.write(data[0] + "\n")
-        tgt_file.write(data[1] + "\n")
-    elif debug:
-        log_file.write(str(data) + "\n")
+def post(data, src_file, tgt_file, debug, log_file, dataset):
+    global NUM_GOOD_LINES
+    global SEGMENT_FROM
+    global DROPPED_FROM
+    resource = dataset.resources[data[0]].file
+    if isinstance(resource, tuple):
+        resource = resource[0]
+    resource = os.path.basename(resource)
+    text = data[1]
+    if not isinstance(text, Exception):
+        if SEGMENT_FROM.get(resource, None) is None:
+            SEGMENT_FROM[resource] = NUM_GOOD_LINES
+        NUM_GOOD_LINES += 1
+        src_file.write(text[0] + "\n")
+        tgt_file.write(text[1] + "\n")
+    else:
+        DROPPED_FROM[resource] = DROPPED_FROM.get(resource, 0) + 1
+        if debug:
+            log_file.write(str(text) + f" from file {resource}\n")
 
 
 class CleanStage(BaseStage):
@@ -91,14 +111,14 @@ class CleanStage(BaseStage):
             with click.progressbar(
                 pool.imap(
                     lambda x: process(x, pipeline),
-                    dataset.read(dataset_reader),
+                    dataset.read(dataset_reader, with_resource_index=True),
                     chunksize=500,
                 ),
                 length=dataset_length,
                 label="Cleaning: ",
             ) as bar:
                 for result in bar:
-                    post(result, src_file, tgt_file, debug, log_file)
+                    post(result, src_file, tgt_file, debug, log_file, dataset)
 
         src_file.close()
         tgt_file.close()
@@ -107,16 +127,11 @@ class CleanStage(BaseStage):
 
         shutil.rmtree(data_dir)
 
-        num_lines = 0
-        with open(
-            os.path.join(self.stage_dir, "data_src.txt"), "r"
-        ) as src_file:
-            for line in src_file:
-                num_lines += 1
-
         output = {
-            "useful": num_lines,
-            "dropped": dataset_length - num_lines,
+            "useful": NUM_GOOD_LINES,
+            "dropped": dataset_length - NUM_GOOD_LINES,
+            "dropped_from": DROPPED_FROM,
+            "resource_intervals": SEGMENT_FROM
         }
 
         return output
