@@ -27,8 +27,8 @@ class InitStage(BaseStage):
                 )
             except Exception as e:
                 print("Error in file", resource.file, ":", str(e))
-                print("Please solve the problem and reset the workflow.")
-                return {}
+                # print("Please solve the problem and reset the workflow.")
+                # return {}
 
         versions_dir = {
             "pangeamt_nlp": pangeamt_nlp.__version__,
