@@ -562,6 +562,11 @@ class PrepareStage(BaseStage):
 
         prev_dir = os.path.join(self.stage_dir, "04_bpe")
 
+        config = self.workflow.project.config
+        shard_size = config.prepare.get("shard_size", "100000")
+        src_seq_length = config.prepare.get("src_seq_length", "100")
+        tgt_seq_length = config.prepare.get("tgt_seq_length", "100")
+
         args = [
             "-train_src",
             os.path.join(prev_dir, "train_src.txt"),
@@ -572,11 +577,11 @@ class PrepareStage(BaseStage):
             "-valid_tgt",
             os.path.join(prev_dir, "dev_tgt.txt"),
             "-shard_size",
-            "100000",
+            shard_size,
             "-src_seq_length",
-            "100",
+            src_seq_length,
             "-tgt_seq_length",
-            "100",
+            tgt_seq_length,
             "-save_data",
             os.path.join(dir, "data"),
             "-log_file",
