@@ -13,18 +13,32 @@ class TrainStage(BaseStage):
     def __init__(self, workflow):
         super().__init__(workflow, self.NAME)
 
-    async def run(self, gpu: int = None):
+    async def run(self, gpu: int = None, continue_from: str = None):
         project = self.workflow.project
         config = project.config
         project_dir = config.project_dir
-
-        name = config.translation_model["name"]
-        args = config.translation_model["args"].split(" ")
-        translation_model = TranslationModelFactory.get_class(name)
-
         workflow_dir = self.workflow.get_dir(project_dir)
         model_dir = os.path.join(workflow_dir, TrainStage.DIR)
-        os.mkdir(model_dir)
+        try:
+            os.mkdir(model_dir)
+        except Exception:
+            pass
+
+        name = config.translation_model["name"]
+        translation_model = TranslationModelFactory.get_class(name)
+        if continue_from is not None:
+            if name == "onmt":
+                args = (
+                    config.translation_model["args"]
+                    + " -train_from "
+                    + os.path.join(model_dir, continue_from)
+                )
+                args = args.split(" ")
+            else:
+                raise Exception("Continue not implemented for " + name)
+        else:
+            args = config.translation_model["args"].split(" ")
+
         prepare_stage = StageFactory.new("prepare", self.workflow)
         prepared_dir = os.path.join(workflow_dir, prepare_stage.DIR)
         data_dir = os.path.join(prepared_dir, "05_batched")
